==> s3-1.7.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/s3/RoutingRuleCondition.java <==
package software.amazon.awscdk.services.s3;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.16.0 (build 98909b5)", date = "2019-09-06T01:04:00.048Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface RoutingRuleCondition extends software.amazon.jsii.JsiiSerializable {
    /**
     * The HTTP error code when the redirect is applied.
     * 
     * In the event of an error, if the error code equals this value, then the specified redirect is applied.
     * 
     * If both condition properties are specified, both must be true for the redirect to be applied.
     * 
     * Default: - The HTTP error code will not be verified
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getHttpErrorCodeReturnedEquals();

    /**
     * The object key name prefix when the redirect is applied.
     * 
     * If both condition properties are specified, both must be true for the redirect to be applied.
     * 
     * Default: - The object key name will not be verified
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getKeyPrefixEquals();

    /**
     * @return a {@link Builder} of {@link RoutingRuleCondition}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link RoutingRuleCondition}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Builder {
        private java.lang.String httpErrorCodeReturnedEquals;
        private java.lang.String keyPrefixEquals;

        /**
         * Sets the value of HttpErrorCodeReturnedEquals
         * @param httpErrorCodeReturnedEquals The HTTP error code when the redirect is applied.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder httpErrorCodeReturnedEquals(java.lang.String httpErrorCodeReturnedEquals) {
            this.httpErrorCodeReturnedEquals = httpErrorCodeReturnedEquals;
            return this;
        }

        /**
         * Sets the value of KeyPrefixEquals
         * @param keyPrefixEquals The object key name prefix when the redirect is applied.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder keyPrefixEquals(java.lang.String keyPrefixEquals) {
            this.keyPrefixEquals = keyPrefixEquals;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link RoutingRuleCondition}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public RoutingRuleCondition build() {
            return new Jsii$Proxy(httpErrorCodeReturnedEquals, keyPrefixEquals);
        }

    }

    /**
     * An implementation for {@link RoutingRuleCondition}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements RoutingRuleCondition {
        private final java.lang.String httpErrorCodeReturnedEquals;
        private final java.lang.String keyPrefixEquals;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
            this.httpErrorCodeReturnedEquals = this.jsiiGet("httpErrorCodeReturnedEquals", java.lang.String.class);
            this.keyPrefixEquals = this.jsiiGet("keyPrefixEquals", java.lang.String.class);
        }


        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(java.lang.String httpErrorCodeReturnedEquals, java.lang.String keyPrefixEquals) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.httpErrorCodeReturnedEquals = httpErrorCodeReturnedEquals;
            this.keyPrefixEquals = keyPrefixEquals;
        }

        @Override
        public java.lang.String getHttpErrorCodeReturnedEquals() {
            return this.httpErrorCodeReturnedEquals;
        }

        @Override
        public java.lang.String getKeyPrefixEquals() {
            return this.keyPrefixEquals;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            if (this.getHttpErrorCodeReturnedEquals() != null) {
                obj.set("httpErrorCodeReturnedEquals", om.valueToTree(this.getHttpErrorCodeReturnedEquals()));
            }
            if (this.getKeyPrefixEquals() != null) {
                obj.set("keyPrefixEquals", om.valueToTree(this.getKeyPrefixEquals()));
            }
            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            RoutingRuleCondition.Jsii$Proxy that = (RoutingRuleCondition.Jsii$Proxy) o;

            if (this.httpErrorCodeReturnedEquals != null ? !this.httpErrorCodeReturnedEquals.equals(that.httpErrorCodeReturnedEquals) : that.httpErrorCodeReturnedEquals != null) return false;
            return this.keyPrefixEquals != null ? this.keyPrefixEquals.equals(that.keyPrefixEquals) : that.keyPrefixEquals == null;
        }

        @Override
        public int hashCode() {
            int result = this.httpErrorCodeReturnedEquals != null ? this.httpErrorCodeReturnedEquals.hashCode() : 0;
            result = 31 * result + (this.keyPrefixEquals != null ? this.keyPrefixEquals.hashCode() : 0);
            return result;
        }

    }
}

==> s3-1.9.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/s3/RoutingRuleCondition.java <==
package software.amazon.awscdk.services.s3;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.17.0 (build 7d5d104)", date = "2019-09-20T09:56:05.224Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface RoutingRuleCondition extends software.amazon.jsii.JsiiSerializable {

    /**
     * The HTTP error code when the redirect is applied.
     * 
     * In the event of an error, if the error code equals this value, then the specified redirect is applied.
     * 
     * If both condition properties are specified, both must be true for the redirect to be applied.
     * 
     * Default: - The HTTP error code will not be verified
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getHttpErrorCodeReturnedEquals();

    /**
     * The object key name prefix when the redirect is applied.
     * 
     * If both condition properties are specified, both must be true for the redirect to be applied.
     * 
     * Default: - The object key name will not be verified
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getKeyPrefixEquals();

    /**
     * @return a {@link Builder} of {@link RoutingRuleCondition}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link RoutingRuleCondition}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder {
        private java.lang.String httpErrorCodeReturnedEquals;
        private java.lang.String keyPrefixEquals;

        /**
         * Sets the value of HttpErrorCodeReturnedEquals
         * @param httpErrorCodeReturnedEquals The HTTP error code when the redirect is applied.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder httpErrorCodeReturnedEquals(java.lang.String httpErrorCodeReturnedEquals) {
            this.httpErrorCodeReturnedEquals = httpErrorCodeReturnedEquals;
            return this;
        }

        /**
         * Sets the value of KeyPrefixEquals
         * @param keyPrefixEquals The object key name prefix when the redirect is applied.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder keyPrefixEquals(java.lang.String keyPrefixEquals) {
            this.keyPrefixEquals = keyPrefixEquals;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link RoutingRuleCondition}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public RoutingRuleCondition build() {
            return new Jsii$Proxy(httpErrorCodeReturnedEquals, keyPrefixEquals);
        }
    }

    /**
     * An implementation for {@link RoutingRuleCondition}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements RoutingRuleCondition {
        private final java.lang.String httpErrorCodeReturnedEquals;
        private final java.lang.String keyPrefixEquals;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
            this.httpErrorCodeReturnedEquals = this.jsiiGet("httpErrorCodeReturnedEquals", java.lang.String.class);
            this.keyPrefixEquals = this.jsiiGet("keyPrefixEquals", java.lang.String.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(java.lang.String httpErrorCodeReturnedEquals, java.lang.String keyPrefixEquals) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.httpErrorCodeReturnedEquals = httpErrorCodeReturnedEquals;
            this.keyPrefixEquals = keyPrefixEquals;
        }

        @Override
        public java.lang.String getHttpErrorCodeReturnedEquals() {
            return this.httpErrorCodeReturnedEquals;
        }

        @Override
        public java.lang.String getKeyPrefixEquals() {
            return this.keyPrefixEquals;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            if (this.getHttpErrorCodeReturnedEquals() != null) {
                obj.set("httpErrorCodeReturnedEquals", om.valueToTree(this.getHttpErrorCodeReturnedEquals()));
            }
            if (this.getKeyPrefixEquals() != null) {
                obj.set("keyPrefixEquals", om.valueToTree(this.getKeyPrefixEquals()));
            }
            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            RoutingRuleCondition.Jsii$Proxy that = (RoutingRuleCondition.Jsii$Proxy) o;

            if (this.httpErrorCodeReturnedEquals != null ? !this.httpErrorCodeReturnedEquals.equals(that.httpErrorCodeReturnedEquals) : that.httpErrorCodeReturnedEquals != null) return false;
            return this.keyPrefixEquals != null ? this.keyPrefixEquals.equals(that.keyPrefixEquals) : that.keyPrefixEquals == null;
        }

        @Override
        public int hashCode() {
            int result = this.httpErrorCodeReturnedEquals != null ? this.httpErrorCodeReturnedEquals.hashCode() : 0;
            result = 31 * result + (this.keyPrefixEquals != null ? this.keyPrefixEquals.hashCode() : 0);
            return result;
        }
    }
}
